from .file.file import File
from .slip.slip import Slip
from .slip.segmentQ import SegmentQ
from .slip.segmentP import SegmentP
from .slip.segmentR import SegmentR
from .result.parser import SlipParser